==> ndarray-base-assert-is-column-major-contiguous-0.0.1.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Determine if an array is column-major contiguous.
*
* @module @stdlib/ndarray/base/assert/is-column-major-contiguous
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 1, 2 ];
* var offset = 0;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns true
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 1, -2 ];
* var offset = 2;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns false
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 2, 2 ];
* var offset = 0;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns false
*/

// MODULES //

var isColumnMajorContiguous = require( './main.js' );


// EXPORTS //

module.exports = isColumnMajorContiguous;

==> ndarray-base-assert-is-column-major-contiguous-0.0.5.tgz: package/lib/index.js <==
/**
* @license Apache-2.0
*
* Copyright (c) 2018 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

'use strict';

/**
* Determine if an array is column-major contiguous.
*
* @module @stdlib/ndarray-base-assert-is-column-major-contiguous
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 1, 2 ];
* var offset = 0;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns true
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 1, -2 ];
* var offset = 2;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns false
*
* @example
* var isColumnMajorContiguous = require( '@stdlib/ndarray-base-assert-is-column-major-contiguous' );
*
* var shape = [ 2, 2 ];
* var strides = [ 2, 2 ];
* var offset = 0;
*
* var bool = isColumnMajorContiguous( shape, strides, offset );
* // returns false
*/

// MODULES //

var isColumnMajorContiguous = require( './main.js' );


// EXPORTS //

module.exports = isColumnMajorContiguous;
